@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2014-2021 GEM Foundation
+# Copyright (C) 2014-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -428,16 +428,20 @@ class HazardCalculator(BaseCalculator):
         """Overridden in event based"""
 
     def check_floating_spinning(self):
+        oq = self.oqparam
         f, s = self.csm.get_floating_spinning_factors()
         if f != 1:
             logging.info('Rupture floating factor = %s', f)
         if s != 1:
             logging.info('Rupture spinning factor = %s', s)
-        if (f * s >= 1.5 and self.oqparam.no_pointsource_distance
-                and 'classical' in self.oqparam.calculation_mode):
+        if (f * s >= 1.5 and oq.no_pointsource_distance
+                and 'classical' in oq.calculation_mode):
             logging.info(
                 'You are not using the pointsource_distance approximation:\n'
                 'https://docs.openquake.org/oq-engine/advanced/common-mistakes.html#pointsource-distance')
+        elif 'classical' in oq.calculation_mode:
+            logging.info('Using pointsource_distance=%s',
+                         oq.pointsource_distance)
 
     def read_inputs(self):
         """
@@ -464,10 +468,10 @@ class HazardCalculator(BaseCalculator):
             with self.monitor('composite source model', measuremem=True):
                 self.csm = csm = readinput.get_composite_source_model(
                     oq, self.datastore.hdf5)
-                mags_by_trt = csm.get_mags_by_trt()
-                for trt in mags_by_trt:
+                oq.mags_by_trt = csm.get_mags_by_trt()
+                for trt in oq.mags_by_trt:
                     self.datastore['source_mags/' + trt] = numpy.array(
-                        mags_by_trt[trt])
+                        oq.mags_by_trt[trt])
                     interp = oq.maximum_distance(trt)
                     if len(interp.x) > 2:
                         md = '%s->%d, ... %s->%d, %s->%d' % (
@@ -478,10 +482,7 @@ class HazardCalculator(BaseCalculator):
                 self.full_lt = csm.full_lt
         self.init()  # do this at the end of pre-execute
         self.pre_checks()
-
-        if (not oq.hazard_calculation_id
-                and oq.calculation_mode != 'preclassical'
-                and not oq.save_disk_space):
+        if oq.calculation_mode == 'multi_risk':
             self.gzip_inputs()
 
         # check DEFINED_FOR_REFERENCE_VELOCITY
@@ -730,10 +731,7 @@ class HazardCalculator(BaseCalculator):
         # site collection, possibly extracted from the exposure.
         oq = self.oqparam
         self.load_crmodel()  # must be called first
-        if (oq.calculation_mode == 'preclassical' and
-                'exposure' not in oq.inputs):
-            return
-        elif (not oq.imtls and 'shakemap' not in oq.inputs
+        if (not oq.imtls and 'shakemap' not in oq.inputs
                 and oq.ground_motion_fields):
             raise InvalidFile('There are no intensity measure types in %s' %
                               oq.inputs['job_ini'])
@@ -776,6 +774,7 @@ class HazardCalculator(BaseCalculator):
                     exposure.exposures, hdf5.vstr)
         elif 'assetcol' in self.datastore.parent:
             assetcol = self.datastore.parent['assetcol']
+            assetcol.update_tagcol(oq.aggregate_by)
             if oq.region:
                 region = wkt.loads(oq.region)
                 self.sitecol = haz_sitecol.within(region)
@@ -828,14 +827,16 @@ class HazardCalculator(BaseCalculator):
                     for taxo, weight in items:
                         if taxo != '?':
                             taxonomies.add(taxo)
-            # check that we are covering all the taxonomy strings in the exposure
+            # check that we are covering all the taxonomies in the exposure
             missing = taxonomies - set(self.crmodel.taxonomies)
             if self.crmodel and missing:
-                raise RuntimeError('The exposure contains the taxonomy strings %s '
-                                   'which are not in the risk model' % missing)
+                raise RuntimeError(
+                    'The exposure contains the taxonomy strings '
+                    '%s which are not in the risk model' % missing)
             if len(self.crmodel.taxonomies) > len(taxonomies):
-                logging.info('Reducing risk model from %d to %d taxonomy strings',
-                             len(self.crmodel.taxonomies), len(taxonomies))
+                logging.info(
+                    'Reducing risk model from %d to %d taxonomy strings',
+                    len(self.crmodel.taxonomies), len(taxonomies))
                 self.crmodel = self.crmodel.reduce(taxonomies)
                 self.crmodel.tmap = tmap
 
@@ -927,8 +928,7 @@ class HazardCalculator(BaseCalculator):
         Save (eff_ruptures, num_sites, calc_time) inside the source_info
         """
         if 'source_info' not in self.datastore:
-            source_reader.create_source_info(
-                self.csm, source_data, self.datastore.hdf5)
+            source_reader.create_source_info(self.csm, self.datastore.hdf5)
         self.csm.update_source_info(source_data)
         recs = [tuple(row) for row in self.csm.source_info.values()]
         self.datastore['source_info'][:] = numpy.array(
@@ -1176,35 +1176,15 @@ def save_agg_values(dstore, assetcol, lossnames, aggby):
     Store agg_keys, agg_values.
     :returns: the aggkey dictionary key -> tags
     """
-    lst = []
-    aggkey = assetcol.tagcol.get_aggkey(aggby)
     if aggby:
-        logging.info('Storing %d aggregation keys', len(aggkey))
-        dt = [(name + '_', U16) for name in aggby] + [
-            (name, hdf5.vstr) for name in aggby]
-        kvs = []
-        for key, val in aggkey.items():
-            val = tuple(python3compat.decode(val))
-            kvs.append(key + val)
-            lst.append(' '.join(val))
-        dstore['agg_keys'] = numpy.array(kvs, dt)
-        if aggby == ['id']:
-            kids = assetcol['ordinal']
-        elif aggby == ['site_id']:
-            kids = assetcol['site_id']
-        else:
-            key2i = {key: i for i, key in enumerate(aggkey)}
-            kids = [key2i[tuple(t)] for t in assetcol[aggby]]
+        aggids, aggtags = assetcol.build_aggids(aggby)
+        logging.info('Storing %d aggregation keys', len(aggids))
+        agg_keys = [','.join(tags) for tags in aggtags]
+        dstore['agg_keys'] = numpy.array(agg_keys, hdf5.vstr)
         if 'assetcol' not in set(dstore):
             dstore['assetcol'] = assetcol
-        grp = dstore.getitem('assetcol')
-        if 'kids' not in grp:
-            grp['kids'] = U16(kids)
-    lst.append('*total*')
     if assetcol.get_value_fields():
         dstore['agg_values'] = assetcol.get_agg_values(aggby)
-        dstore.set_shape_descr('agg_values', aggregation=lst)
-    return aggkey if aggby else {}
 
 
 def read_shakemap(calc, haz_sitecol, assetcol):
@@ -1293,7 +1273,10 @@ def create_risk_by_event(calc):
     """
     oq = calc.oqparam
     dstore = calc.datastore
-    aggkey = getattr(calc, 'aggkey', {})  # empty if not aggregate_by
+    try:
+        K = len(dstore['agg_keys'])
+    except KeyError:
+        K = 0
     crmodel = calc.crmodel
     if 'risk' in oq.calculation_mode:
         fields = [('loss', F32)]
@@ -1301,11 +1284,10 @@ def create_risk_by_event(calc):
             fields.append(('ins_loss', F32))
         descr = [('event_id', U32), ('agg_id', U32), ('loss_id', U8),
                  ('variance', F32)] + fields
-        dstore.create_df('risk_by_event', descr, K=len(aggkey),
-                         L=len(oq.loss_types))
+        dstore.create_df('risk_by_event', descr, K=K, L=len(oq.loss_types))
     else:  # damage + consequences
         dmgs = ' '.join(crmodel.damage_states[1:])
         descr = ([('event_id', U32), ('agg_id', U32), ('loss_id', U8)] +
                  [(dc, F32) for dc in crmodel.get_dmg_csq()])
-        dstore.create_df('risk_by_event', descr, K=len(aggkey),
+        dstore.create_df('risk_by_event', descr, K=K,
                          L=len(oq.loss_types), limit_states=dmgs)
