@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2015-2021 GEM Foundation
+# Copyright (C) 2015-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -246,6 +246,9 @@ class DisaggregationCalculator(base.HazardCalculator):
         Run the disaggregation phase.
         """
         oq = self.oqparam
+        ws = [rlz.weight for rlz in self.full_lt.get_realizations()]
+        if oq.rlz_index is None and oq.num_rlzs_disagg == 0:
+            oq.num_rlzs_disagg = len(ws)  # 0 means all rlzs
         edges, self.shapedic = disagg.get_edges_shapedic(
             oq, self.sitecol, self.datastore['source_mags'])
         self.save_bin_edges(edges)
@@ -253,7 +256,6 @@ class DisaggregationCalculator(base.HazardCalculator):
         self.poes_disagg = oq.poes_disagg or (None,)
         self.imts = list(oq.imtls)
         self.M = len(self.imts)
-        ws = [rlz.weight for rlz in self.full_lt.get_realizations()]
         dstore = (self.datastore.parent if self.datastore.parent
                   else self.datastore)
         nrows = len(dstore['_poes/sid'])
@@ -262,7 +264,7 @@ class DisaggregationCalculator(base.HazardCalculator):
 
         # build array rlzs (N, Z)
         if oq.rlz_index is None:
-            Z = oq.num_rlzs_disagg or 1
+            Z = oq.num_rlzs_disagg
             rlzs = numpy.zeros((self.N, Z), int)
             if self.R > 1:
                 for sid in self.sitecol.sids:
