@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2015-2021 GEM Foundation
+# Copyright (C) 2015-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -223,14 +223,7 @@ class EventBasedCalculator(base.HazardCalculator):
         eff_ruptures = AccumDict(accum=0)  # grp_id => potential ruptures
         source_data = AccumDict(accum=[])
         allargs = []
-        if self.oqparam.is_ucerf():
-            # manage the filtering in a special way
-            for sg in self.csm.src_groups:
-                for src in sg:
-                    src.src_filter = self.srcfilter
-            srcfilter = nofilter  # otherwise it would be ultra-slow
-        else:
-            srcfilter = self.srcfilter
+        srcfilter = self.srcfilter
         logging.info('Building ruptures')
         for sg in self.csm.src_groups:
             if not sg.sources:
@@ -328,8 +321,9 @@ class EventBasedCalculator(base.HazardCalculator):
                     '%s for a scenario calculation must contain a single '
                     'branchset, found %d!' % (oq.inputs['job_ini'], bsets))
             [(trt, rlzs_by_gsim)] = gsim_lt.get_rlzs_by_gsim_trt().items()
-            self.cmaker = ContextMaker(trt, rlzs_by_gsim, oq)
             rup = readinput.get_rupture(oq)
+            oq.mags_by_trt = {trt: ['%.2f' % rup.mag]}
+            self.cmaker = ContextMaker(trt, rlzs_by_gsim, oq)
             if self.N > oq.max_sites_disagg:  # many sites, split rupture
                 ebrs = [EBRupture(copyobj(rup, rup_id=rup.rup_id + i),
                                   'NA', 0, G, e0=i * G, scenario=True)
