@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2014-2021 GEM Foundation
+# Copyright (C) 2014-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -21,7 +21,7 @@ import collections
 import numpy
 import pandas
 
-from openquake.baselib import hdf5, writers, general, python3compat
+from openquake.baselib import hdf5, writers, general
 from openquake.hazardlib.stats import compute_stats2
 from openquake.risklib import scientific
 from openquake.calculators.extract import (
@@ -52,24 +52,65 @@ def tag2idx(tags):
     return {tag: i for i, tag in enumerate(tags)}
 
 
-def get_agg_tags(dstore, aggregate_by):
-    agg_tags = {}
-    if aggregate_by:
-        agg_keys = dstore['agg_keys'][:]
-        for tagname in aggregate_by:
-            keys = python3compat.decode(agg_keys[tagname])
-            agg_tags[tagname] = numpy.concatenate([keys, ['*total*']])
-    else:
-        agg_tags = {}
-    return agg_tags
-
-
 def _loss_type(ln):
     if ln[-4:] == '_ins':
         return ln[:-4]
     return ln
 
 
+def get_aggtags(dstore):
+    # returns a list of tag tuples
+    if 'agg_keys' in dstore:  # there was an aggregate_by
+        aggtags = [ln.decode('utf8').split(',')
+                   for ln in dstore['agg_keys'][:]]
+        aggtags += [('*total*',) * len(aggtags[0])]
+    else:  # np aggregate_by
+        aggtags = [()]
+    return aggtags
+
+
+def _aggrisk(oq, aggids, aggtags, agg_values, aggrisk, md, dest):
+    writer = writers.CsvWriter(fmt=writers.FIVEDIGITS)
+    cols = [col for col in aggrisk.columns
+            if col not in {'agg_id', 'rlz_id', 'loss_id'}]
+    csqs = [col for col in cols if not col.startswith('dmg_')]
+    manyrlzs = hasattr(aggrisk, 'rlz_id') and len(aggrisk.rlz_id.unique()) > 1
+    fnames = []
+    K = len(agg_values) - 1
+    pairs = [([], aggrisk.agg_id == K)]  # full aggregation
+    for tagnames, agg_ids in zip(oq.aggregate_by, aggids):
+        pairs.append((tagnames, numpy.isin(aggrisk.agg_id, agg_ids)))
+    for tagnames, ok in pairs:
+        header = ['loss_type'] + tagnames + ['exposed_value'] + [
+            '%s_ratio' % csq for csq in csqs]
+        out = general.AccumDict(accum=[])
+        for (agg_id, lid), df in aggrisk[ok].groupby(['agg_id', 'loss_id']):
+            n = len(df)
+            loss_type = oq.loss_types[lid]
+            out['loss_type'].extend([loss_type] * n)
+            if tagnames:
+                for tagname, tag in zip(tagnames, aggtags[agg_id]):
+                    out[tagname].extend([tag] * n)
+            if manyrlzs:
+                out['rlz_id'].extend(df.rlz_id)
+            for col in cols:
+                if col in csqs:  # normally csqs = ['loss']
+                    aval = scientific.get_agg_value(
+                        col, agg_values, agg_id, loss_type)
+                    out[col + '_value'].extend(df[col])
+                    out[col + '_ratio'].extend(df[col] / aval)
+                else:
+                    out[col].extend(df[col])
+        dsdic = {'dmg_0': 'no_damage'}
+        for s, ls in enumerate(oq.limit_states, 1):
+            dsdic['dmg_%d' % s] = ls
+        df = pandas.DataFrame(out).rename(columns=dsdic)
+        fname = dest.format('-'.join(tagnames))
+        writer.save(df, fname, header, comment=md)
+        fnames.append(fname)
+    return fnames
+
+
 @export.add(('aggrisk', 'csv'))
 def export_aggrisk(ekey, dstore):
     """
@@ -77,48 +118,17 @@ def export_aggrisk(ekey, dstore):
     :param dstore: datastore object
     """
     oq = dstore['oqparam']
-    tagnames = oq.aggregate_by
-    writer = writers.CsvWriter(fmt=writers.FIVEDIGITS)
-    tagcol = dstore['assetcol/tagcol']
-    aggtags = list(tagcol.get_aggkey(tagnames).values())
-    aggtags.append(('*total*',) * len(tagnames))
-    agg_values = dstore['agg_values'][()]  # shape K+1
+    assetcol = dstore['assetcol']
     md = dstore.metadata
     md.update(dict(investigation_time=oq.investigation_time,
                    risk_investigation_time=oq.risk_investigation_time or
                    oq.investigation_time))
 
     aggrisk = dstore.read_df('aggrisk')
-    cols = [col for col in aggrisk.columns
-            if col not in {'agg_id', 'rlz_id', 'loss_id'}]
-    csqs = [col for col in cols if not col.startswith('dmg_')]
-    header = ['loss_type'] + tagnames + ['exposed_value'] + [
-        '%s_ratio' % csq for csq in csqs]
-    dest = dstore.build_fname('aggrisk', '', 'csv')
-    out = general.AccumDict(accum=[])
-    manyrlzs = hasattr(aggrisk, 'rlz_id') and len(aggrisk.rlz_id.unique()) > 1
-    for (agg_id, loss_id), df in aggrisk.groupby(['agg_id', 'loss_id']):
-        n = len(df)
-        loss_type = oq.loss_types[loss_id]
-        out['loss_type'].extend([loss_type] * n)
-        for tagname, tag in zip(tagnames, aggtags[agg_id]):
-            out[tagname].extend([tag] * n)
-        if manyrlzs:
-            out['rlz_id'].extend(df.rlz_id)
-        for col in cols:
-            if col in csqs:
-                aval = scientific.get_agg_value(
-                    col, agg_values, agg_id, loss_type)
-                out[col + '_value'].extend(df[col])
-                out[col + '_ratio'].extend(df[col] / aval)
-            else:
-                out[col].extend(df[col])
-    dsdic = {'dmg_0': 'no_damage'}
-    for s, ls in enumerate(oq.limit_states, 1):
-        dsdic['dmg_%d' % s] = ls
-    df = pandas.DataFrame(out).rename(columns=dsdic)
-    writer.save(df, dest, header, comment=md)
-    return [dest]
+    dest = dstore.build_fname('aggrisk-{}', '', 'csv')
+    agg_values = assetcol.get_agg_values(oq.aggregate_by)
+    aggids, aggtags = assetcol.build_aggids(oq.aggregate_by)
+    return _aggrisk(oq, aggids, aggtags, agg_values, aggrisk, md, dest)
 
 
 @export.add(('aggrisk-stats', 'csv'), ('aggcurves-stats', 'csv'))
@@ -128,19 +138,29 @@ def export_aggrisk_stats(ekey, dstore):
     :param dstore: datastore object
     """
     oq = dstore['oqparam']
-    tagcol = dstore['assetcol/tagcol']
-    aggtags = list(tagcol.get_aggkey(oq.aggregate_by).values())
-    aggtags.append(('*total*',) * len(oq.aggregate_by))
     key = ekey[0].split('-')[0]  # aggrisk or aggcurves
     writer = writers.CsvWriter(fmt=writers.FIVEDIGITS)
-    dest = dstore.build_fname(f'{key}-stats', '', 'csv')
-    df = extract(dstore, f'risk_stats/{key}')
-    tagvalues = numpy.array([aggtags[agg_id] for agg_id in df.agg_id])
-    for n, name in enumerate(oq.aggregate_by):
-        df[name] = tagvalues[:, n]
-    del df['agg_id']
-    writer.save(df, dest, df.columns, comment=dstore.metadata)
-    return [dest]
+    dest = dstore.build_fname(key + '-stats-{}', '', 'csv')
+    dataf = extract(dstore, 'risk_stats/' + key)
+    assetcol = dstore['assetcol']
+    agg_values = assetcol.get_agg_values(oq.aggregate_by)
+    K = len(agg_values) - 1
+    aggids, aggtags = assetcol.build_aggids(oq.aggregate_by)
+    pairs = [([], dataf.agg_id == K)]  # full aggregation
+    for tagnames, agg_ids in zip(oq.aggregate_by, aggids):
+        pairs.append((tagnames, numpy.isin(dataf.agg_id, agg_ids)))
+    fnames = []
+    for tagnames, ok in pairs:
+        df = dataf[ok]
+        if tagnames:
+            tagvalues = numpy.array([aggtags[agg_id] for agg_id in df.agg_id])
+            for n, name in enumerate(tagnames):
+                df[name] = tagvalues[:, n]
+        del df['agg_id']
+        fname = dest.format('-'.join(tagnames))
+        writer.save(df, fname, df.columns, comment=dstore.metadata)
+        fnames.append(fname)
+    return fnames
 
 
 def _get_data(dstore, dskey, stats):
@@ -492,6 +512,7 @@ def export_aggregate_by_csv(ekey, dstore):
     return fnames
 
 
+# used in multi_risk
 @export.add(('asset_risk', 'csv'))
 def export_asset_risk_csv(ekey, dstore):
     """
@@ -527,6 +548,7 @@ def export_asset_risk_csv(ekey, dstore):
     return [fname]
 
 
+# used in multi_risk
 @export.add(('agg_risk', 'csv'))
 def export_agg_risk_csv(ekey, dstore):
     """
@@ -548,16 +570,17 @@ def export_aggcurves_csv(ekey, dstore):
     :param dstore: datastore object
     """
     oq = dstore['oqparam']
+    assetcol = dstore['assetcol']
+    agg_values = assetcol.get_agg_values(oq.aggregate_by)
+    aggids, aggtags = assetcol.build_aggids(oq.aggregate_by)
     E = len(dstore['events'])
     R = len(dstore['weights'])
+    K = len(dstore['agg_values']) - 1
     lossnames = numpy.array(oq.loss_types)
-    aggtags = get_agg_tags(dstore, oq.aggregate_by)
-    df = dstore.read_df('aggcurves')
-    consequences = [col for col in df.columns
+    dataf = dstore.read_df('aggcurves')
+    consequences = [col for col in dataf.columns
                     if col in scientific.KNOWN_CONSEQUENCES]
-    for tagname, tags in aggtags.items():
-        df[tagname] = tags[df.agg_id]
-    dest = dstore.export_path('%s.%s' % ekey)
+    dest = dstore.export_path('%s-{}.%s' % ekey)
     writer = writers.CsvWriter(fmt=writers.FIVEDIGITS)
     md = dstore.metadata
     md['risk_investigation_time'] = (oq.risk_investigation_time or
@@ -568,22 +591,32 @@ def export_aggcurves_csv(ekey, dstore):
     md['limit_states'] = dstore.get_attr('aggcurves', 'limit_states')
 
     # aggcurves
-    agg_values = dstore['agg_values'][:]
-    cols = [col for col in df.columns if col not in consequences
+    cols = [col for col in dataf.columns if col not in consequences
             and col not in ('agg_id', 'rlz_id', 'loss_id')]
     edic = general.AccumDict(accum=[])
     manyrlzs = not oq.collect_rlzs and R > 1
-    for (agg_id, rlz_id, loss_id), d in df.groupby(
-            ['agg_id', 'rlz_id', 'loss_id']):
-        for col in cols:
-            edic[col].extend(d[col])
-        edic['loss_type'].extend([lossnames[loss_id]] * len(d))
-        if manyrlzs:
-            edic['rlz_id'].extend([rlz_id] * len(d))
-        for cons in consequences:
-            edic[cons + '_value'].extend(d[cons])
-            aval = scientific.get_agg_value(
-                cons, agg_values, agg_id, lossnames[loss_id])
-            edic[cons + '_ratio'].extend(d[cons] / aval)
-    writer.save(pandas.DataFrame(edic), dest, comment=md)
-    return [dest]
+    fnames = []
+    pairs = [([], dataf.agg_id == K)]  # full aggregation
+    for tagnames, agg_ids in zip(oq.aggregate_by, aggids):
+        pairs.append((tagnames, numpy.isin(dataf.agg_id, agg_ids)))
+    for tagnames, ok in pairs:
+        edic = general.AccumDict(accum=[])
+        for (agg_id, rlz_id, loss_id), d in dataf[ok].groupby(
+                ['agg_id', 'rlz_id', 'loss_id']):
+            if tagnames:
+                for tagname, tag in zip(tagnames, aggtags[agg_id]):
+                    edic[tagname].extend([tag] * len(d))
+            for col in cols:
+                edic[col].extend(d[col])
+            edic['loss_type'].extend([lossnames[loss_id]] * len(d))
+            if manyrlzs:
+                edic['rlz_id'].extend([rlz_id] * len(d))
+            for cons in consequences:
+                edic[cons + '_value'].extend(d[cons])
+                aval = scientific.get_agg_value(
+                    cons, agg_values, agg_id, lossnames[loss_id])
+                edic[cons + '_ratio'].extend(d[cons] / aval)
+        fname = dest.format('-'.join(tagnames))
+        writer.save(pandas.DataFrame(edic), fname, comment=md)
+        fnames.append(fname)
+    return fnames
