@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2014-2021 GEM Foundation
+# Copyright (C) 2014-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -28,7 +28,7 @@ import collections
 import multiprocessing
 import numpy
 
-from openquake.baselib import __version__, hdf5, python3compat
+from openquake.baselib import __version__, hdf5, python3compat, config
 from openquake.baselib.general import DictArray, AccumDict
 from openquake.hazardlib.imt import from_string
 from openquake.hazardlib.shakemap.maps import get_array
@@ -36,6 +36,7 @@ from openquake.hazardlib import correlation, cross_correlation, stats, calc
 from openquake.hazardlib import valid, InvalidFile, site
 from openquake.sep.classes import SecondaryPeril
 from openquake.commonlib import logictree
+from openquake.risklib import asset
 from openquake.risklib.riskmodels import get_risk_files
 
 __doc__ = """\
@@ -64,8 +65,8 @@ reaggregate_by:
 amplification_method:
   Used in classical PSHA calculations to amplify the hazard curves with
   the convolution or kernel method.
-  Example: *amplification_method = convolution*.
-  Default: None
+  Example: *amplification_method = kernel*.
+  Default: "convolution"
 
 area_source_discretization:
   Discretization parameters (in km) for area sources.
@@ -113,6 +114,11 @@ base_path:
 cachedir:
   INTERNAL
 
+cache_distances:
+  Useful in UCERF calculations.
+  Example: *cache_distances = true*.
+  Default: False
+
 calculation_mode:
   One of classical, disaggregation, event_based, scenario, scenario_risk,
   scenario_damage, event_based_risk, classical_risk, classical_bcr.
@@ -482,9 +488,9 @@ num_epsilon_bins:
 
 num_rlzs_disagg:
   Used in disaggregation calculation to specify how many outputs will be
-  generated.
-  Example: *num_rlzs_disagg=1*.
-  Default: None
+  generated. `0` means all realizations.
+  Example: *num_rlzs_disagg=0*.
+  Default: 1
 
 number_of_ground_motion_fields:
   Used in scenario calculations to specify how many random ground motion
@@ -517,7 +523,7 @@ ps_grid_spacing:
   Used in classical calculations to grid the point sources. Requires the
   *pointsource_distance* to be set too.
   Example: *ps_grid_spacing = 50*.
-  Default: no default
+  Default: 0, meaning no grid
 
 quantiles:
   List of probabilities used to compute the quantiles across realizations.
@@ -593,17 +599,11 @@ rupture_mesh_spacing:
   Example: *rupture_mesh_spacing = 2.0*.
   Default: 5.0
 
-ruptures_per_block:
-  INTERNAL
-
 sampling_method:
   One of early_weights, late_weights, early_latin, late_latin)
   Example: *sampling_method = early_latin*.
   Default: 'early_weights'
 
-save_disk_space:
- INTERNAL
-
 sec_peril_params:
   INTERNAL
 
@@ -705,7 +705,7 @@ time_per_task:
   Used in calculatins with task splitting. If a task slice takes longer
   then *time_per_task* seconds, then spawn subtasks for the other slices.
   Example: *time_per_task=600*
-  Default: 300
+  Default: 2000
 
 truncation_level:
   Truncation level used in the GMPEs.
@@ -728,6 +728,10 @@ width_of_mfd_bin:
   Default: None
 """ % __version__
 
+try:
+    PSDIST = config.performance.pointsource_distance
+except AttributeError:
+    PSDIST = 1000
 GROUND_MOTION_CORRELATION_MODELS = ['JB2009', 'HM2018']
 TWO16 = 2 ** 16  # 65536
 TWO32 = 2 ** 32
@@ -736,6 +740,22 @@ U32 = numpy.uint32
 U64 = numpy.uint64
 F32 = numpy.float32
 F64 = numpy.float64
+ALL_CALCULATORS = ['classical_risk',
+                   'classical_damage',
+                   'classical',
+                   'event_based',
+                   'scenario',
+                   'post_risk',
+                   'ebrisk',
+                   'scenario_risk',
+                   'event_based_risk',
+                   'disaggregation',
+                   'multi_risk',
+                   'classical_bcr',
+                   'preclassical',
+                   'conditional_spectrum',
+                   'event_based_damage',
+                   'scenario_damage']
 
 
 def check_same_levels(imtls):
@@ -791,10 +811,10 @@ class OqParam(valid.ParamSet):
                'max_hazard_curves': 'max'}
 
     hazard_imtls = {}
-    aggregate_by = valid.Param(valid.namelist, [])
+    aggregate_by = valid.Param(valid.namelists, [])
     reaggregate_by = valid.Param(valid.namelist, [])
     amplification_method = valid.Param(
-        valid.Choice('convolution', 'kernel'), None)
+        valid.Choice('convolution', 'kernel'), 'convolution')
     minimum_asset_loss = valid.Param(valid.floatdict, {'default': 0})
     area_source_discretization = valid.Param(
         valid.NoneOr(valid.positivefloat), None)
@@ -803,9 +823,9 @@ class OqParam(valid.ParamSet):
     assets_per_site_limit = valid.Param(valid.positivefloat, 1000)
     avg_losses = valid.Param(valid.boolean, True)
     base_path = valid.Param(valid.utf8, '.')
-    calculation_mode = valid.Param(valid.Choice())  # -> get_oqparam
+    calculation_mode = valid.Param(valid.Choice(*ALL_CALCULATORS))
     collapse_gsim_logic_tree = valid.Param(valid.namelist, [])
-    collapse_level = valid.Param(valid.Choice('0', '1', '2', '3'), '0')
+    collapse_level = valid.Param(int, -1)
     collect_rlzs = valid.Param(valid.boolean, None)
     coordinate_bin_width = valid.Param(valid.positivefloat)
     compare_with_classical = valid.Param(valid.boolean, False)
@@ -816,6 +836,7 @@ class OqParam(valid.ParamSet):
     cross_correlation = valid.Param(valid.utf8_not_empty, 'yes')
     cholesky_limit = valid.Param(valid.positiveint, 10_000)
     cachedir = valid.Param(valid.utf8, '')
+    cache_distances = valid.Param(valid.boolean, False)
     description = valid.Param(valid.utf8_not_empty, "no description")
     disagg_by_src = valid.Param(valid.boolean, False)
     disagg_outputs = valid.Param(valid.disagg_outputs,
@@ -876,11 +897,11 @@ class OqParam(valid.ParamSet):
     number_of_ground_motion_fields = valid.Param(valid.positiveint)
     number_of_logic_tree_samples = valid.Param(valid.positiveint, 0)
     num_epsilon_bins = valid.Param(valid.positiveint, 1)
-    num_rlzs_disagg = valid.Param(valid.positiveint, None)
+    num_rlzs_disagg = valid.Param(valid.positiveint, 1)
     poes = valid.Param(valid.probabilities, [])
     poes_disagg = valid.Param(valid.probabilities, [])
-    pointsource_distance = valid.Param(valid.floatdict, {'default': 1000})
-    ps_grid_spacing = valid.Param(valid.positivefloat, None)
+    pointsource_distance = valid.Param(valid.floatdict, {'default': PSDIST})
+    ps_grid_spacing = valid.Param(valid.positivefloat, 0)
     quantile_hazard_curves = quantiles = valid.Param(valid.probabilities, [])
     random_seed = valid.Param(valid.positiveint, 42)
     reference_depth_to_1pt0km_per_sec = valid.Param(
@@ -901,11 +922,9 @@ class OqParam(valid.ParamSet):
     complex_fault_mesh_spacing = valid.Param(
         valid.NoneOr(valid.positivefloat), None)
     return_periods = valid.Param(valid.positiveints, [])
-    ruptures_per_block = valid.Param(valid.positiveint, 500)  # for UCERF
     sampling_method = valid.Param(
         valid.Choice('early_weights', 'late_weights',
                      'early_latin', 'late_latin'), 'early_weights')
-    save_disk_space = valid.Param(valid.boolean, False)
     secondary_perils = valid.Param(valid.namelist, [])
     sec_peril_params = valid.Param(valid.dictionary, {})
     secondary_simulations = valid.Param(valid.dictionary, {})
@@ -927,7 +946,7 @@ class OqParam(valid.ParamSet):
     outs_per_task = valid.Param(valid.positiveint, 4)
     ebrisk_maxsize = valid.Param(valid.positivefloat, 2E10)  # used in ebrisk
     time_event = valid.Param(str, None)
-    time_per_task = valid.Param(valid.positivefloat, 600)
+    time_per_task = valid.Param(valid.positivefloat, 2000)
     truncation_level = valid.Param(valid.NoneOr(valid.positivefloat), None)
     uniform_hazard_spectra = valid.Param(valid.boolean, False)
     vs30_tolerance = valid.Param(valid.positiveint, 0)
@@ -1028,6 +1047,8 @@ class OqParam(valid.ParamSet):
                 'pointsource_distance' not in names_vals):
             raise InvalidFile('%s: ps_grid_spacing requires setting a '
                               'pointsource_distance!' % self.inputs['job_ini'])
+        if self.collapse_level >= 0:
+            self.time_per_task = 1_000_000  # disable task_splitting
 
         self._risk_files = get_risk_files(self.inputs)
         if self.risk_files:
@@ -1083,11 +1104,6 @@ class OqParam(valid.ParamSet):
             self.poes = 1 - numpy.exp(
                 - self.investigation_time / numpy.array(self.return_periods))
 
-        # check for multi_risk
-        if self.calculation_mode == 'multi_risk':
-            # store input files, mandatory for the QGIS plugin
-            self.save_disk_space = False
-
         # check for tiling
         if self.max_sites_disagg > self.max_sites_per_tile:
             raise ValueError(
@@ -1118,8 +1134,7 @@ class OqParam(valid.ParamSet):
             if self.disagg_outputs and not any(
                     'Eps' in out for out in self.disagg_outputs):
                 self.num_epsilon_bins = 1
-            if (self.rlz_index is not None
-                    and self.num_rlzs_disagg is not None):
+            if self.rlz_index is not None and self.num_rlzs_disagg != 1:
                 raise InvalidFile('%s: you cannot set rlzs_index and '
                                   'num_rlzs_disagg at the same time' % job_ini)
 
@@ -1173,12 +1188,6 @@ class OqParam(valid.ParamSet):
                                           'disaggregation']):
             check_same_levels(self.imtls)
 
-        if ('amplification' in self.inputs and
-            self.amplification_method == 'convolution' and not
-                self.soil_intensities):
-            raise InvalidFile('%s: The soil_intensities must be defined'
-                              % job_ini)
-
     def validate(self):
         """
         Set self.loss_types
@@ -1283,13 +1292,13 @@ class OqParam(valid.ParamSet):
         """
         if self.investigation_time is None:
             # for scenarios there is no effective_time
-            return [1] * len(num_events)
+            return numpy.full_like(num_events, len(num_events))
         else:
             # for event based compute the time_ratio
             time_ratio = self.time_ratio
             if self.collect_rlzs:
                 time_ratio /= num_haz_rlzs
-            return list(time_ratio * num_events)
+            return time_ratio * num_events
 
     @property
     def imtls(self):
@@ -1568,13 +1577,7 @@ class OqParam(valid.ParamSet):
         The calculation mode is event_based, event_based_risk or ebrisk
         """
         return (self.calculation_mode in
-                'event_based_risk ebrisk event_based_damage ucerf_hazard')
-
-    def is_ucerf(self):
-        """
-        :returns: True for UCERF calculations, False otherwise
-        """
-        return 'source_model' in self.inputs
+                'event_based_risk ebrisk event_based_damage')
 
     def is_valid_shakemap(self):
         """
@@ -1713,16 +1716,20 @@ class OqParam(valid.ParamSet):
         """
         `ps_grid_spacing` must be smaller than the `pointsource_distance`
         """
-        if self.ps_grid_spacing is None:
+        if not self.ps_grid_spacing:
             return True
         return self.ps_grid_spacing <= calc.filters.getdefault(
             self.pointsource_distance, 'default')
 
     def is_valid_soil_intensities(self):
         """
-        soil_intensities can be set only if amplification_method=convolution
+        soil_intensities must be defined only in classical calculations
+        with amplification_method=convolution
         """
-        if self.amplification_method == 'convolution':
+        classical = ('classical' in self.calculation_mode or
+                     'disaggregation' in self.calculation_mode)
+        if (classical and 'amplification' in self.inputs and
+                self.amplification_method == 'convolution'):
             return len(self.soil_intensities) > 1
         else:
             return self.soil_intensities is None
@@ -1743,9 +1750,10 @@ class OqParam(valid.ParamSet):
         At the moment only `aggregate_by=id` or `aggregate_by=site_id`
         are accepted
         """
-        if 'id' in self.aggregate_by and len(self.aggregate_by) > 1:
+        tagset = asset.tagset(self.aggregate_by)
+        if 'id' in tagset and len(tagset) > 1:
             return False
-        elif 'site_id' in self.aggregate_by and len(self.aggregate_by) > 1:
+        elif 'site_id' in tagset and len(tagset) > 1:
             return False
         return True
 
