@@ -25,7 +25,7 @@ import zlib
 import numpy
 
 from openquake.baselib import parallel, general, hdf5
-from openquake.hazardlib import nrml, sourceconverter, InvalidFile
+from openquake.hazardlib import nrml, sourceconverter, InvalidFile, pmf, geo
 from openquake.hazardlib.contexts import basename
 from openquake.hazardlib.calc.filters import magstr
 from openquake.hazardlib.lt import apply_uncertainties
@@ -46,7 +46,7 @@ source_info_dt = numpy.dtype([
 ])
 
 
-def create_source_info(csm, source_data, h5):
+def create_source_info(csm, h5):
     """
     Creates source_info, source_wkt, trt_smrs, toms
     """
@@ -57,8 +57,9 @@ def create_source_info(csm, source_data, h5):
         for src in sg:
             srcid = basename(src)
             trti = csm.full_lt.trti.get(src.tectonic_region_type, -1)
+            code = csm.code.get(srcid, b'P')
             lens.append(len(src.trt_smrs))
-            row = [srcid, src.grp_id, src.code, 0, 0, 0, trti, 0]
+            row = [srcid, src.grp_id, code, 0, 0, 0, trti, 0]
             wkts.append(getattr(src, '_wkt', ''))
             data[srcid] = row
             src.id = len(data) - 1
@@ -108,6 +109,25 @@ def _check_dupl_ids(src_groups):
                 first = False
 
 
+def collapse_nphc(src):
+    """
+    Collapse the nodal_plane_distribution and hypocenter_distribution.
+    """
+    if (hasattr(src, 'nodal_plane_distribution') and
+            hasattr(src, 'hypocenter_distribution')):
+        if len(src.nodal_plane_distribution.data) > 1:
+            ws, nps = zip(*src.nodal_plane_distribution.data)
+            strike = numpy.average([np.strike for np in nps], weights=ws)
+            dip = numpy.average([np.dip for np in nps], weights=ws)
+            rake = numpy.average([np.rake for np in nps], weights=ws)
+            val = geo.NodalPlane(strike, dip, rake)
+            src.nodal_plane_distribution = pmf.PMF([(1., val)])
+        if len(src.hypocenter_distribution.data) > 1:
+            ws, vals = zip(*src.hypocenter_distribution.data)
+            val = numpy.average(vals, weights=ws)
+            src.hypocenter_distribution = pmf.PMF([(1., val)])
+
+
 def get_csm(oq, full_lt, h5=None):
     """
     Build source models from the logic tree and to store
@@ -117,38 +137,12 @@ def get_csm(oq, full_lt, h5=None):
         oq.investigation_time, oq.rupture_mesh_spacing,
         oq.complex_fault_mesh_spacing, oq.width_of_mfd_bin,
         oq.area_source_discretization, oq.minimum_magnitude,
-        oq.source_id, discard_trts=oq.discard_trts,
+        oq.source_id,
+        discard_trts=[s.strip() for s in oq.discard_trts.split(',')],
         floating_x_step=oq.floating_x_step,
         floating_y_step=oq.floating_y_step)
     classical = not oq.is_event_based()
     full_lt.ses_seed = oq.ses_seed
-    if oq.is_ucerf():
-        [grp] = nrml.to_python(oq.inputs["source_model"], converter)
-        src_groups = []
-        for grp_id, sm_rlz in enumerate(full_lt.sm_rlzs):
-            sg = copy.copy(grp)
-            src_groups.append(sg)
-            src = sg[0].new(sm_rlz.ordinal, sm_rlz.value[0])  # one source
-            src.checksum = src.grp_id = src.trt_smr = grp_id
-            src.samples = sm_rlz.samples
-            logging.info('Reading sections and rupture planes for %s', src)
-            planes = src.get_planes()
-            if classical:
-                src.ruptures_per_block = oq.ruptures_per_block
-                sg.sources = list(src)
-                for s in sg:
-                    s.planes = planes
-                    s.sections = s.get_sections()
-                # add background point sources
-                sg = copy.copy(grp)
-                src_groups.append(sg)
-                sg.sources = src.get_background_sources()
-            else:  # event_based, use one source
-                sg.sources = [src]
-                src.planes = planes
-                src.sections = src.get_sections()
-        return CompositeSourceModel(full_lt, src_groups)
-
     logging.info('Reading the source model(s) in parallel')
 
     # NB: the source models file are often NOT in the shared directory
@@ -171,6 +165,14 @@ def get_csm(oq, full_lt, h5=None):
     if changes:
         logging.info('Applied {:_d} changes to the composite source model'.
                      format(changes))
+
+    if 'reqv' in oq.inputs:
+        logging.warning('Using equivalent distance approximation and '
+                        'collapsing finite size parameters in point sources')
+        for group in groups:
+            for src in group:
+                collapse_nphc(src)
+
     return _get_csm(full_lt, groups)
 
 
@@ -181,20 +183,25 @@ def fix_geometry_sections(smdict):
     """
     gmodels = []
     smodels = []
+    gfiles = []
     for fname, mod in smdict.items():
         if isinstance(mod, nrml.GeometryModel):
             gmodels.append(mod)
+            gfiles.append(fname)
         elif isinstance(mod, nrml.SourceModel):
             smodels.append(mod)
         else:
             raise RuntimeError('Unknown model %s' % mod)
 
     # merge and reorder the sections
+    sec_ids = []
     sections = {}
     for gmod in gmodels:
+        sec_ids.extend(gmod.sections)
         sections.update(gmod.sections)
+    nrml.check_unique(
+        sec_ids, 'section ID in files ' + ' '.join(gfiles))
     sections = {sid: sections[sid] for sid in sorted(sections)}
-    nrml.check_unique(sections)
 
     # fix the MultiFaultSources
     for smod in smodels:
@@ -220,6 +227,7 @@ def _build_groups(full_lt, smdict):
     smlt_file = full_lt.source_model_lt.filename
     smlt_dir = os.path.dirname(smlt_file)
     groups = []
+    frac = 1. / len(full_lt.sm_rlzs)
     for rlz in full_lt.sm_rlzs:
         src_groups, source_ids = _groups_ids(
             smlt_dir, smdict, rlz.value[0].split())
@@ -238,6 +246,9 @@ def _build_groups(full_lt, smdict):
             sg = apply_uncertainties(bset_values, src_group)
             for src in sg:
                 src.trt_smr = trt_smr
+                # the smweight is used in event based sampling:
+                # see oq-risk-tests etna
+                src.smweight = rlz.weight if full_lt.num_samples else frac
                 if rlz.samples > 1:
                     src.samples = rlz.samples
             groups.append(sg)
@@ -263,7 +274,7 @@ def reduce_sources(sources_with_same_id):
     out = []
     for src in sources_with_same_id:
         dic = {k: v for k, v in vars(src).items()
-               if k not in 'source_id trt_smr samples'}
+               if k not in 'source_id trt_smr smweight samples'}
         src.checksum = zlib.adler32(pickle.dumps(dic, protocol=4))
     for srcs in general.groupby(
             sources_with_same_id, operator.attrgetter('checksum')).values():
@@ -334,10 +345,13 @@ class CompositeSourceModel:
         self.sm_rlzs = full_lt.sm_rlzs
         self.full_lt = full_lt
         self.src_groups = src_groups
+        self.code = {}  # srcid -> code
         for grp_id, sg in enumerate(src_groups):
             assert len(sg)  # sanity check
             for src in sg:
                 src.grp_id = grp_id
+                if src.code != b'P':
+                    self.code[src.source_id] = src.code
 
     def get_trt_smrs(self):
         """
@@ -455,8 +469,6 @@ class CompositeSourceModel:
                 logging.info(msg.format(src, src.num_ruptures, spc))
         assert tot_weight
         max_weight = tot_weight / (oq.concurrent_tasks or 1)
-        if parallel.Starmap.num_cores > 64:  # if many cores less tasks
-            max_weight *= 1.5
         logging.info('tot_weight={:_d}, max_weight={:_d}, num_sources={:_d}'.
                      format(int(tot_weight), int(max_weight), len(srcs)))
         heavy = [src for src in srcs if src.weight > max_weight]
