@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2012-2021 GEM Foundation
+# Copyright (C) 2012-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -30,7 +30,6 @@ from openquake.baselib import hdf5
 from openquake.baselib.general import AccumDict
 from openquake.baselib.performance import Monitor
 from openquake.baselib.python3compat import raise_
-from openquake.hazardlib.contexts import basename
 from openquake.hazardlib.calc.filters import nofilter, SourceFilter
 from openquake.hazardlib.source.rupture import (
     BaseRupture, EBRupture, rupture_dt)
@@ -263,8 +262,9 @@ def sample_ruptures(sources, cmaker, sitecol=None, monitor=Monitor()):
 
         # Yield ruptures
         er = sum(src.num_ruptures for src, _ in srcfilter.filter(sources))
-        yield AccumDict(dict(rup_array=get_rup_array(eb_ruptures, srcfilter),
-                             source_data=source_data, eff_ruptures={grp_id: er}))
+        dic = dict(rup_array=get_rup_array(eb_ruptures, srcfilter),
+                   source_data=source_data, eff_ruptures={grp_id: er})
+        yield AccumDict(dic)
     else:
         eb_ruptures = []
         eff_ruptures = 0
