@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2015-2021 GEM Foundation
+# Copyright (C) 2015-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -82,11 +82,8 @@ def get_stress_factor(imt, slab):
     Returns the stress adjustment factor for the BC Hydro GMPE according to
     Abrahamson et al. (2018)
     """
-    if slab:
-        sigma_mu = BCHYDRO_SIGMA_MU[imt]["SIGMA_MU_SSLAB"]
-    else:
-        sigma_mu = BCHYDRO_SIGMA_MU[imt]["SIGMA_MU_SINTER"]
-    return sigma_mu / 1.65
+    C = BCHYDRO_SIGMA_MU[imt]
+    return (C["SIGMA_MU_SSLAB"] if slab else C["SIGMA_MU_SINTER"]) / 1.65
 
 
 def _compute_magterm(C1, theta1, theta4, theta5, theta13, dc1, mag):
@@ -96,10 +93,9 @@ def _compute_magterm(C1, theta1, theta4, theta5, theta13, dc1, mag):
     """
     base = theta1 + theta4 * dc1
     dmag = C1 + dc1
-    f_mag = np.where(mag > dmag,
-                     theta5 * (mag - dmag) + theta13 * (10. - mag) ** 2.,
-                     theta4 * (mag - dmag) + theta13 * (10. - mag) ** 2.)
-    return base + f_mag
+    f_mag = np.where(
+        mag > dmag, theta5 * (mag - dmag), theta4 * (mag - dmag))
+    return base + f_mag + theta13 * (10. - mag) ** 2.
 
 
 # theta6_adj used in BCHydro
@@ -112,9 +108,9 @@ def _compute_disterm(trt, C1, theta2, theta14, theta3, ctx, c4, theta9,
         dists = ctx.rhypo
     else:
         raise NotImplementedError(trt)
-    return ((theta2 + theta14 + theta3 * (ctx.mag - C1)) * np.log(
-        dists + c4 * np.exp((ctx.mag - 6.) * theta9)) +
-            (theta6_adj + theta6) * dists) + theta10
+    return (theta2 + theta14 + theta3 * (ctx.mag - C1)) * np.log(
+        dists + c4 * np.exp((ctx.mag - 6.) * theta9)) + (
+        theta6_adj + theta6) * dists + theta10
 
 
 def _compute_forearc_backarc_term(trt, faba_model, C, ctx):
@@ -176,11 +172,8 @@ def _compute_focal_depth_term(trt, C, ctx):
     indicated by equation (3)
     """
     if trt == const.TRT.SUBDUCTION_INTERFACE:
-        return 0.
-    if ctx.hypo_depth > 120.0:
-        z_h = 120.0
-    else:
-        z_h = ctx.hypo_depth
+        return np.zeros_like(ctx.mag)
+    z_h = np.clip(ctx.hypo_depth, None, 120.)
     return C['theta11'] * (z_h - 60.)
 
 
@@ -262,7 +255,7 @@ class AbrahamsonEtAl2015SInter(GMPE):
     DEFINED_FOR_INTENSITY_MEASURE_TYPES = {PGA, SA}
 
     #: Supported intensity measure component is the geometric mean component
-    DEFINED_FOR_INTENSITY_MEASURE_COMPONENT = const.IMC.AVERAGE_HORIZONTAL
+    DEFINED_FOR_INTENSITY_MEASURE_COMPONENT = const.IMC.GEOMETRIC_MEAN
 
     #: Supported standard deviation types are inter-event, intra-event
     #: and total, see table 3, pages 12 - 13
@@ -302,7 +295,7 @@ class AbrahamsonEtAl2015SInter(GMPE):
         else:
             self.faba_model = None
 
-    def compute(self, ctx, imts, mean, sig, tau, phi):
+    def compute(self, ctx: np.recarray, imts, mean, sig, tau, phi):
         """
         See :meth:`superclass method
         <.base.GroundShakingIntensityModel.compute>`
@@ -470,9 +463,8 @@ class AbrahamsonEtAl2015SInter_scaled(AbrahamsonEtAl2015SInter):
 
     Application of a scaling factor that converts the prediction of
     AbrahamsonEtAl2015SInter to the corresponding
-    prediction for the Maximum value. 
+    prediction for the Maximum value.
     """
-    
     # Period-dependent coefficients
     COEFFS = CoeffsTable(sa_damping=5, table="""\
 	IMT		vlin	b		theta1		theta2	theta6		theta7	theta8	theta10	theta11	theta12	theta13	theta14	theta15	theta16	phi	tau		sigma	sigma_ss
@@ -503,10 +495,10 @@ class AbrahamsonEtAl2015SSlab_scaled(AbrahamsonEtAl2015SInter_scaled):
     considered to be a point source located at the hypocentre. Therefore
     the hypocentral distance metric is used in place of the rupture distance,
     and the hypocentral depth is used to scale the ground motion by depth
-    
+
     Application of a scaling factor that converts the prediction of
     AbrahamsonEtAl2015SSlab to the corresponding
-    prediction for the Maximum value. 
+    prediction for the Maximum value.
     """
     #: Supported tectonic region type is subduction in-slab
     DEFINED_FOR_TECTONIC_REGION_TYPE = trt = const.TRT.SUBDUCTION_INTRASLAB
