@@ -21,7 +21,7 @@ import itertools
 import collections
 import numpy
 
-from openquake.baselib.general import CallableDict, BASE64
+from openquake.baselib.general import CallableDict, BASE94
 from openquake.hazardlib import geo, source as ohs
 from openquake.hazardlib.sourceconverter import (
     split_coords_2d, split_coords_3d)
@@ -127,7 +127,7 @@ def complexGeom(utype, node, filename):
 @parse_uncertainty.add('characteristicFaultGeometryAbsolute')
 def charGeom(utype, node, filename):
     surfaces = []
-    for geom_node in node.surface:
+    for i, geom_node in enumerate(node.surface):
         if "simpleFaultGeometry" in geom_node.tag:
             _validate_simple_fault_geometry(utype, geom_node, filename)
             trace, usd, lsd, dip, spacing = parse_uncertainty(
@@ -150,6 +150,7 @@ def charGeom(utype, node, filename):
             top_left, top_right, bottom_right, bottom_left = tuple(nodes)
             surface = geo.PlanarSurface.from_corner_points(
                 top_left, top_right, bottom_right, bottom_left)
+            surface.suid = f'{i}'
             surfaces.append(surface)
         else:
             raise LogicTreeError(
@@ -556,10 +557,6 @@ class BranchSet(object):
             This filter is required for absolute uncertainties (also
             only one source can be used for those). Value should be the list
             of source ids. Can be used only in source model logic tree.
-        applyToSourceType
-            Can be used in the source model logic tree definition. Allows
-            to specify to which source type (area, point, simple fault,
-            complex fault) the uncertainty applies to.
         applyToTectonicRegionType
             Can be used in both the source model and GMPE logic trees. Allows
             to specify to which tectonic region type (Active Shallow Crust,
@@ -655,26 +652,6 @@ class BranchSet(object):
             if key == 'applyToTectonicRegionType':
                 if value != source.tectonic_region_type:
                     return False
-            elif key == 'applyToSourceType':
-                if value == 'area':
-                    if not isinstance(source, ohs.AreaSource):
-                        return False
-                elif value == 'point':
-                    # area source extends point source
-                    if (not isinstance(source, ohs.PointSource)
-                            or isinstance(source, ohs.AreaSource)):
-                        return False
-                elif value == 'simpleFault':
-                    if not isinstance(source, ohs.SimpleFaultSource):
-                        return False
-                elif value == 'complexFault':
-                    if not isinstance(source, ohs.ComplexFaultSource):
-                        return False
-                elif value == 'characteristicFault':
-                    if not isinstance(source, ohs.CharacteristicFaultSource):
-                        return False
-                else:
-                    raise AssertionError("unknown source type '%s'" % value)
             elif key == 'applyToSources':
                 if source and source.source_id not in value:
                     return False
@@ -780,7 +757,7 @@ class CompositeLogicTree(object):
         for bsno, bset in enumerate(branchsets):
             for brno, br in enumerate(bset.branches):
                 path = ['*'] * nb
-                path[bsno] = br.short_id = BASE64[brno]
+                path[bsno] = br.short_id = BASE94[brno]
                 paths.append(''.join(path))
         self.basepaths = paths
 
