@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2018-2021 GEM Foundation
+# Copyright (C) 2018-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -33,7 +33,10 @@ import json
 import zipfile
 
 from shapely.geometry import Polygon
-import shapefile
+try:
+    import shapefile  # optional dependency
+except ImportError:
+    pass
 
 import numpy
 from openquake.baselib.general import CallableDict
