@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2012-2021 GEM Foundation
+# Copyright (C) 2012-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -162,9 +162,17 @@ site_param_dt = {
     'precip': numpy.float64,
     'fpeak': numpy.float64,
 
+    # parameters for YoudEtAl2002
+    'freeface_ratio': numpy.float64,
+    'T_15': numpy.float64,
+    'D50_15': numpy.float64,
+    'F_15': numpy.float64,
+    'T_eq': numpy.float64,
+
     # other parameters
     'custom_site_id': (numpy.string_, 6),
-    'region': numpy.uint32
+    'region': numpy.uint32,
+    'in_cshm': bool  # used in mcverry
 }
 
 
