@@ -1,6 +1,6 @@
 # coding: utf-8
 # The Hazard Library
-# Copyright (C) 2012-2021 GEM Foundation
+# Copyright (C) 2012-2022 GEM Foundation
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -284,7 +284,7 @@ class BaseRupture(metaclass=abc.ABCMeta):
         self.hypocenter = hypocenter
         self.surface = surface
         self.rupture_slip_direction = rupture_slip_direction
-        self.weight = weight
+        self.ruid = None
 
     @property
     def code(self):
@@ -350,7 +350,8 @@ class NonParametricProbabilisticRupture(BaseRupture):
             rupture_slip_direction, weight)
         # an array of probabilities with sum 1
         self.probs_occur = numpy.array([prob for (prob, occ) in pmf.data])
-        self.occurrence_rate = numpy.nan
+        if weight is not None:
+            self.weight = weight
 
     def sample_number_of_occurrences(self, n=1):
         """
@@ -604,7 +605,6 @@ class PointRupture(ParametricProbabilisticRupture):
         self.occurrence_rate = occurrence_rate
         self.temporal_occurrence_model = temporal_occurrence_model
         self.surface = PointSurface(hypocenter, strike)
-        self.weight = None  # no mutex
 
 
 def get_geom(surface, is_from_fault_source, is_multi_surface,
