@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2015-2021 GEM Foundation
+# Copyright (C) 2015-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -95,6 +95,21 @@ def fix_dupl(dist, fname=None, lineno=None):
             dist[:] = newdist
 
 
+def rounded_unique(mags, idxs):
+    """
+    :param mags: a list of magnitudes
+    :param idxs: a list of tuples of section indices
+    :returns: an array of magnitudes rounded to 2 digits
+    :raises: ValueError if the rounded magnitudes contain duplicates
+    """
+    mags = numpy.round(mags, 2)
+    mag_idxs = list(zip(mags, idxs))
+    dupl = extract_dupl(mag_idxs)
+    if dupl:
+        logging.error('%s %s contains duplicates' % dupl[0])
+    return mags
+
+
 class SourceGroup(collections.abc.Sequence):
     """
     A container for the following parameters:
@@ -379,30 +394,31 @@ def convert_nonParametricSeismicSource(fname, node, rup_spacing=5.0):
     nps = source.NonParametricSeismicSource(
         node['id'], node['name'], trt, [], [])
     nps.splittable = 'rup_weights' not in node.attrib
-    path = os.path.splitext(fname)[0] + '.hdf5'
-    hdf5_fname = path if os.path.exists(path) else None
-    if hdf5_fname and node.text is None:
-        # gridded source, read the rupture data from the HDF5 file
-        with hdf5.File(hdf5_fname, 'r') as h:
-            dic = {k: d[:] for k, d in h[node['id']].items()}
-            nps.fromdict(dic, rups_weights)
-    else:
-        # read the rupture data from the XML nodes
-        num_probs = None
-        for i, rupnode in enumerate(node):
-            po = rupnode['probs_occur']
-            probs = pmf.PMF(valid.pmf(po))
-            if num_probs is None:  # first time
-                num_probs = len(probs.data)
-            elif len(probs.data) != num_probs:
-                # probs_occur must have uniform length for all ruptures
-                raise ValueError(
-                    'prob_occurs=%s has %d elements, expected %s'
-                    % (po, len(probs.data), num_probs))
-            rup = RuptureConverter(rup_spacing).convert_node(rupnode)
-            rup.tectonic_region_type = trt
-            rup.weight = None if rups_weights is None else rups_weights[i]
-            nps.data.append((rup, probs))
+    if fname:
+        path = os.path.splitext(fname)[0] + '.hdf5'
+        hdf5_fname = path if os.path.exists(path) else None
+        if hdf5_fname and node.text is None:
+            # gridded source, read the rupture data from the HDF5 file
+            with hdf5.File(hdf5_fname, 'r') as h:
+                dic = {k: d[:] for k, d in h[node['id']].items()}
+                nps.fromdict(dic, rups_weights)
+                return nps
+    # read the rupture data from the XML nodes
+    num_probs = None
+    for i, rupnode in enumerate(node):
+        po = rupnode['probs_occur']
+        probs = pmf.PMF(valid.pmf(po))
+        if num_probs is None:  # first time
+            num_probs = len(probs.data)
+        elif len(probs.data) != num_probs:
+            # probs_occur must have uniform length for all ruptures
+            raise ValueError(
+                'prob_occurs=%s has %d elements, expected %s'
+                % (po, len(probs.data), num_probs))
+        rup = RuptureConverter(rup_spacing).convert_node(rupnode)
+        rup.tectonic_region_type = trt
+        rup.weight = None if rups_weights is None else rups_weights[i]
+        nps.data.append((rup, probs))
     return nps
 
 
@@ -585,7 +601,7 @@ class RuptureConverter(object):
             surface=self.convert_surfaces(surfaces))
         return rupt
 
-    # used in scenario only (?)
+    # used in scenarios or nonparametric sources
     def convert_multiPlanesRupture(self, node):
         """
         Convert a multiPlanesRupture node.
@@ -658,7 +674,7 @@ class SourceConverter(RuptureConverter):
                  complex_fault_mesh_spacing=None, width_of_mfd_bin=1.0,
                  area_source_discretization=None,
                  minimum_magnitude={'default': 0},
-                 source_id=None, discard_trts='',
+                 source_id=None, discard_trts=(),
                  floating_x_step=0, floating_y_step=0):
         self.investigation_time = investigation_time
         self.area_source_discretization = area_source_discretization
@@ -1063,6 +1079,7 @@ class SourceConverter(RuptureConverter):
         return convert_nonParametricSeismicSource(
             self.fname, node, self.rupture_mesh_spacing)
 
+    # used in UCERF
     def convert_multiFaultSource(self, node):
         """
         Convert the given node into a multi fault source object.
@@ -1087,14 +1104,17 @@ class SourceConverter(RuptureConverter):
                 num_probs = len(prb.data)
             elif len(prb.data) != num_probs:
                 # probs_occur must have uniform length for all ruptures
-                raise ValueError(
-                    'prob_occurs=%s has %d elements, expected %s'
-                    % (rupnode['probs_occur'], len(prb.data), num_probs))
+                with context(self.fname, rupnode):
+                    raise ValueError(
+                        'prob_occurs=%s has %d elements, expected %s'
+                        % (rupnode['probs_occur'], len(prb.data), num_probs))
             pmfs.append(prb)
             mags.append(~rupnode.magnitude)
             rakes.append(~rupnode.rake)
-            idxs.append(rupnode.sectionIndexes.get('indexes').split(','))
-        mags = numpy.array(mags)
+            indexes = rupnode.sectionIndexes['indexes']
+            idxs.append(tuple(indexes.split(',')))
+        with context(self.fname, node):
+            mags = rounded_unique(mags, idxs)
         rakes = numpy.array(rakes)
         # NB: the sections will be fixed later on, in source_reader
         mfs = MultiFaultSource(sid, name, trt, idxs, pmfs, mags, rakes)
@@ -1241,7 +1261,7 @@ class RowConverter(SourceConverter):
     def convert_npdist(self, node):
         lst = []
         for w, np in super().convert_npdist(node).data:
-            dic = {'weight': w, 'dip': np.dip, 'rake': np.rake,
+            dic = {'probability': w, 'dip': np.dip, 'rake': np.rake,
                    'strike': np.strike}
             lst.append(dic)
         return str(lst)
@@ -1249,7 +1269,7 @@ class RowConverter(SourceConverter):
     def convert_hddist(self, node):
         lst = []
         for w, hd in super().convert_hddist(node).data:
-            lst.append(dict(weight=w, hypodepth=hd))
+            lst.append(dict(probability=w, hypodepth=hd))
         return str(lst)
 
     def convert_areaSource(self, node):
