@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 #
-# Copyright (C) 2015-2021 GEM Foundation
+# Copyright (C) 2015-2022 GEM Foundation
 #
 # OpenQuake is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License as published
@@ -138,7 +138,8 @@ def store(request_files, ini, calc_id):
     if arch is None:
         # move each file to calc_dir using the upload file names
         inifiles = []
-        for each_file in sorted(request_files.values()):
+        # NB: request_files.values() Django objects are not sortable
+        for each_file in request_files.values():
             new_path = os.path.join(calc_dir, each_file.name)
             shutil.move(each_file.temporary_file_path(), new_path)
             if each_file.name.endswith(ini):
